@@ -1,10 +1,11 @@
 #' Concatenate factors, combining levels
 #'
-#' This is useful way of patching together factors from multiple sources
+#' This is a useful way of patching together factors from multiple sources
 #' that really should have the same levels but don't.
 #'
-#' @param fs A factor, or list of factors.
-#' @param ... Individual factors
+#' @param ... <[`dynamic-dots`][rlang::dyn-dots]> Individual
+#'   factors. Uses tidy dots, so you can splice in a list of factors
+#'   with `!!!`.
 #' @export
 #' @examples
 #' fa <- factor("a")
@@ -14,23 +15,19 @@
 #' c(fa, fb, fab)
 #' fct_c(fa, fb, fab)
 #'
-#' # You can also pass a list of factors as the first argument
+#' # You can also pass a list of factors with !!!
 #' fs <- list(fa, fb, fab)
-#' fct_c(fs)
-fct_c <- function(fs, ...) {
-  if (is.list(fs)) {
-    fs <- c(fs, list(...))
-  } else {
-    fs <- c(list(fs), list(...))
-  }
-  fs <- check_factor_list(fs)
+#' fct_c(!!!fs)
+fct_c <- function(...) {
+  fs <- list2(...)
+  fs <- check_factor_list(fs, "...")
 
   if (length(fs) == 0) {
     return(factor())
   }
 
   levels <- lvls_union(fs)
-  all <- unlist(fct_unify(fs, levels))
+  all <- unlist(fct_unify(fs, levels), use.names = FALSE)
   factor(all, levels = levels, exclude = NULL)
 }
 
