@@ -1,9 +1,9 @@
 #' Low-level functions for manipulating levels
 #'
-#' `lvls_reorder` leaves values as is, but changes the order.
+#' `lvls_reorder` leaves values as they are, but changes the order.
 #' `lvls_revalue` changes the values of existing levels; there must
 #' be one new level for each old level.
-#' `lvls_extend` extends the set of levels; the new level must
+#' `lvls_expand` expands the set of levels; the new levels must
 #' include the old levels.
 #'
 #' These functions are less helpful than the higher-level `fct_` functions,
@@ -11,9 +11,9 @@
 #' because they are more specific, and hence can more carefully check their
 #' arguments.
 #'
-#' @param f A factor
-#' @param idx A integer index, with one integer for each existing level
-#' @param new_levels A character vector of new levels
+#' @param f A factor (or character vector).
+#' @param idx A integer index, with one integer for each existing level.
+#' @param new_levels A character vector of new levels.
 #' @param ordered A logical which determines the "ordered" status of the
 #'   output factor. `NA` preserves the existing status of the factor.
 #' @name lvls
@@ -29,10 +29,10 @@ NULL
 lvls_reorder <- function(f, idx, ordered = NA) {
   f <- check_factor(f)
   if (!is.numeric(idx)) {
-    stop("`idx` must be numeric", call. = FALSE)
+    cli::cli_abort("{.arg idx} must be numeric")
   }
   if (!setequal(idx, lvls_seq(f)) || length(idx) != nlevels(f)) {
-    stop("`idx` must contain one integer for each level of `f`", call. = FALSE)
+    cli::cli_abort("{.arg idx} must contain one integer for each level of {.arg f}")
   }
 
   refactor(f, levels(f)[idx], ordered = ordered)
@@ -44,28 +44,43 @@ lvls_revalue <- function(f, new_levels) {
   f <- check_factor(f)
 
   if (!is.character(new_levels)) {
-    stop("`new_levels` must be a character vector", call. = FALSE)
+    cli::cli_abort("{.arg new_levels} must be a character vector")
   }
 
   if (length(new_levels) != nlevels(f)) {
-    stop(
-      "`new_levels` must be the same length as `levels(f)`: expected ",
-      nlevels(f), " new levels, got ", length(new_levels), ".",
-      call. = FALSE)
+    n_new <- length(new_levels)
+    n_old <- nlevels(f)
+    cli::cli_abort(
+      "{.arg new_levels} must be the same length ({n_new}) as {.code levels(f)} ({n_old})."
+    )
   }
 
-  levels(f) <- new_levels
-  f
+  if (anyDuplicated(new_levels)) {
+    # Collapse levels, creating a new factor
+    u_levels <- unique(new_levels)
+    index <- match(new_levels, u_levels)
+
+    out <- index[f]
+    attributes(out) <- attributes(f)
+    attr(out, "levels") <- u_levels
+    out
+  } else {
+    attr(f, "levels") <- new_levels
+    f
+  }
 }
 
 #' @export
 #' @rdname lvls
 lvls_expand <- function(f, new_levels) {
+  f <- check_factor(f)
+
   missing <- setdiff(levels(f), new_levels)
   if (length(missing) > 0) {
-    stop(
-      "Must include all existing levels. Missing: ", paste0(missing, collapse = ", "),
-      call. = FALSE)
+    cli::cli_abort(c(
+      "{.arg new_levels} must include all levels in {.arg f}.",
+      i = "Missing {length(missing)} level{?s}: {missing}"
+    ))
   }
 
   refactor(f, new_levels)
