@@ -1,9 +1,11 @@
 #' Replace levels with "other"
 #'
 #' @inheritParams fct_lump
-#' @param keep,drop `keep` will preserve listed levels, replacing all others
-#'   with `other_level`. `drop` will replace listed levels with `other_level`,
-#'   keeping all others as they are.
+#' @param keep,drop Pick one of `keep` and `drop`:
+#'   * `keep` will preserve listed levels, replacing all others with
+#'     `other_level`.
+#'   * `drop` will replace listed levels with `other_level`, keeping all
+#'     as is.
 #' @seealso [fct_lump()] to automatically convert the rarest (or most
 #'    common) levels to "other".
 #' @export
@@ -14,10 +16,7 @@
 #' fct_other(x, drop = c("A", "B"))
 fct_other <- function(f, keep, drop, other_level = "Other") {
   f <- check_factor(f)
-
-  if (!xor(missing(keep), missing(drop))) {
-    stop("Must supply one of `keep` and `drop`", call. = FALSE)
-  }
+  check_exclusive(keep, drop)
 
   levels <- levels(f)
   if (!missing(keep)) {
