@@ -1,10 +1,10 @@
 #' Change factor levels by hand
 #'
 #' @param .f A factor (or character vector).
-#' @param ... <[`dynamic-dots`][rlang::dyn-dots]> A sequence of named character vectors where the
-#'   name gives the new level, and the value gives the old level.
-#'   Levels not otherwise mentioned will be left as is. Levels can
-#'   be removed by naming them `NULL`. Uses tidy dots.
+#' @param ... <[`dynamic-dots`][rlang::dyn-dots]> A sequence of named character
+#'   vectors where the name gives the new level, and the value gives the old
+#'   level. Levels not otherwise mentioned will be left as is. Levels can
+#'   be removed by naming them `NULL`.
 #' @export
 #' @examples
 #' x <- factor(c("apple", "bear", "banana", "dear"))
@@ -16,6 +16,9 @@
 #' # If you name the level NULL it will be removed
 #' fct_recode(x, NULL = "apple", fruit = "banana")
 #'
+#' # Wrap the left hand side in quotes if it contains special variables
+#' fct_recode(x, "an apple" = "apple", "a bear" = "bear")
+#'
 #' # When passing a named vector to rename levels use !!! to splice
 #' x <- factor(c("apple", "bear", "banana", "dear"))
 #' levels <- c(fruit = "apple", fruit = "banana")
@@ -50,18 +53,21 @@ fct_recode <- function(.f, ...) {
   lvls_revalue(f, old_levels)
 }
 
-check_recode_levels <- function(...) {
-  levels <- rlang::list2(...)
+check_recode_levels <- function(..., call = caller_env()) {
+  levels <- list2(...)
 
   is_ok <- function(x) is.character(x) && length(x) == 1
-  ok <- vapply(levels, is_ok, logical(1))
+  ok <- vapply(levels, is_ok, logical(1)) & names2(levels) != ""
 
   if (!all(ok)) {
-    stop(
-      "Each input to fct_recode must be a single named string. ",
-      "Problems at positions: ", paste0(which(!ok), collapse = ", "),
-      call. = FALSE
-    )
+    indx <- names2(levels)
+    indx[indx == ""] <- seq_along(levels)[indx == ""]
+    problems <- indx[!ok]
+
+    cli::cli_abort(c(
+      "Each element of {.arg ...} must be a named string.",
+      i = "Problems with {length(problems)} argument{?s}: {problems}"
+    ), call = call)
   }
 
   unlist(levels)
